# Predecons-GUI
Predecons-GUI is a gradio based front end for predecons a ml tool for building / transferlearning llms
## Installation
```bash
pip install predacons-gui
```
## Usage
```python
import predacons_gui
predacons_gui.launch()
```

```bash
predacons-gui
```
## Features
- [x] Gradio based front end
- [x] Predecons based backend
- [x] abitly to load, save and train over hugging face models
- [x] abitly to test and train over custom models and any hugging face model

## Screenshots
![image](https://github.com/shouryashashank/predacons-gui/assets/25346465/7010c8c6-e557-4cf8-8985-edfc06c23832)
![image](https://github.com/shouryashashank/predacons-gui/assets/25346465/60354ec7-09bb-4179-b4e9-e478d6a630b8)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
Please make sure to update tests as appropriate.
## License
[MIT](https://choosealicense.com/licenses/mit/)
